==> auth-2.3.0911.2-sources.jar: com/zing/zalo/zalosdk/auth/internal/f.java <==
package com.zing.zalo.zalosdk.auth.internal;

import android.content.Context;
import android.os.AsyncTask;
import com.zing.zalo.zalosdk.core.helper.AppInfo;
import com.zing.zalo.zalosdk.core.helper.Base64;
import com.zing.zalo.zalosdk.core.helper.Utils;
import com.zing.zalo.zalosdk.core.http.HttpClientRequest;
import com.zing.zalo.zalosdk.core.http.HttpClientRequest.Type;
import com.zing.zalo.zalosdk.core.log.Log;
import com.zing.zalo.zalosdk.oauth.ZaloSDK;
import org.json.JSONObject;

final class f extends AsyncTask<b, Void, c> {
    a a;
    Context b;

    static class c {
        int b;
        String c;
        String d;
        long e;
        String f;
        String g;

        c() {
        }
    }

    interface a {
        void a(c cVar);
    }

    static class b {
        String a;
        String b;
        String c;
        String d;

        b() {
        }
    }

    f(Context context, a aVar) {
        this.b = context;
        this.a = aVar;
    }

    private c a(b... bVarArr) {
        c anonymousClass1 = new c(this) {
            final /* synthetic */ f a;

            {
                this.a = r5;
                this.b = -1;
                this.c = this.a.b.getString(Utils.getResourceId(this.a.b, "txt_retry_error", "string"));
            }
        };
        if (bVarArr.length == 0) {
            return anonymousClass1;
        }
        b bVar = bVarArr[0];
        if ("0999666666".equalsIgnoreCase(bVar.b)) {
            try {
                Thread.sleep(1000);
                return "6666".equalsIgnoreCase(bVar.c) ? new c(this) {
                    final /* synthetic */ f a;

                    {
                        this.a = r3;
                        this.b = 0;
                        this.c = "";
                        this.d = "1234567890";
                        this.e = 1234567890;
                        this.f = "first last";
                        this.g = "1";
                    }
                } : new c(this) {
                    final /* synthetic */ f a;

                    {
                        this.a = r2;
                        this.b = -1;
                        this.c = "Mã kích hoạt không chính xác.";
                    }
                };
            } catch (InterruptedException e) {
                return anonymousClass1;
            }
        }
        try {
            HttpClientRequest httpClientRequest = new HttpClientRequest(Type.POST, "https://oauth.zaloapp.com/v2/mobile/register/confirm-code");
            httpClientRequest.addParams("app_id", ZaloSDK.Instance.getAppID());
            httpClientRequest.addParams("pkg_name", this.b.getPackageName());
            httpClientRequest.addParams("sign_key", AppInfo.getApplicationHashKey(this.b));
            httpClientRequest.addParams("zdId", ZaloSDK.Instance.getDeviceId());
            httpClientRequest.addParams("sdkId", ZaloSDK.Instance.getSDKId());
            httpClientRequest.addParams("conn", Utils.getConnectionType(this.b));
            httpClientRequest.addParams("mod", Utils.getDeviceModel());
            httpClientRequest.addParams("heap", Utils.getHeapSize());
            httpClientRequest.addParams("deviceWidth", String.valueOf(Utils.getScreenWidth(this.b)));
            httpClientRequest.addParams("deviceHeight", String.valueOf(Utils.getScreenHeight(this.b)));
            httpClientRequest.addParams("imei", Utils.getIMEI(this.b));
            httpClientRequest.addParams("localTime", String.valueOf(System.currentTimeMillis()));
            httpClientRequest.addParams("timeZone", Utils.getTimeZoneString());
            httpClientRequest.addParams("cpuProcessor", Utils.getCPUInfo());
            httpClientRequest.addParams("battery", Utils.getBatteryInfo());
            httpClientRequest.addParams("phone", bVar.b);
            httpClientRequest.addParams("regionCode", bVar.a);
            httpClientRequest.addParams("token", bVar.d);
            httpClientRequest.addParams("lang", com.zing.zalo.zalosdk.payment.direct.Utils.getLanguage(this.b));
            httpClientRequest.addParams("activeCode", Base64.encode(Utils.encrypt(ZaloSDK.Instance.getPrivateKey(), bVar.c)));
            JSONObject json = httpClientRequest.getJSON();
            anonymousClass1.b = json.optInt("error", -1);
            anonymousClass1.c = json.optString("errorMsg", anonymousClass1.c);
            json = json.optJSONObject("data");
            if (anonymousClass1.b != 0 || json == null) {
                return anonymousClass1;
            }
            anonymousClass1.d = json.optString("token", "");
            anonymousClass1.e = json.optLong("uid", 0);
            anonymousClass1.f = json.optString("display_name", "");
            anonymousClass1.g = json.optString("gender", "");
            return anonymousClass1;
        } catch (Exception e2) {
            Log.e(e2);
            return anonymousClass1;
        }
    }

    protected final /* synthetic */ Object doInBackground(Object[] objArr) {
        return a((b[]) objArr);
    }

    protected final /* synthetic */ void onPostExecute(Object obj) {
        c cVar = (c) obj;
        super.onPostExecute(cVar);
        if (this.a != null) {
            this.a.a(cVar);
        }
        this.a = null;
    }
}

==> auth-2.3.0911.6-sources.jar: com/zing/zalo/zalosdk/auth/internal/f.java <==
package com.zing.zalo.zalosdk.auth.internal;

import android.content.Context;
import android.os.AsyncTask;
import com.zing.zalo.zalosdk.core.helper.AppInfo;
import com.zing.zalo.zalosdk.core.helper.Utils;
import com.zing.zalo.zalosdk.core.http.HttpClientRequest;
import com.zing.zalo.zalosdk.core.http.HttpClientRequest.Type;
import com.zing.zalo.zalosdk.core.log.Log;
import com.zing.zalo.zalosdk.oauth.ZaloSDK;
import org.json.JSONObject;

final class f extends AsyncTask<b, Void, c> {
    a a;
    Context b;

    static class c {
        int b;
        String c;
        String d;
        String e;

        c() {
        }
    }

    interface a {
        void a(c cVar);
    }

    static class b {
        boolean a;
        String b;
        String c;

        b() {
        }
    }

    f(Context context, a aVar) {
        this.b = context;
        this.a = aVar;
    }

    private c a(b... bVarArr) {
        c anonymousClass1 = new c(this) {
            final /* synthetic */ f a;

            {
                this.a = r5;
                this.b = -1;
                this.c = this.a.b.getString(Utils.getResourceId(this.a.b, "txt_retry_error", "string"));
            }
        };
        if (bVarArr.length == 0) {
            return anonymousClass1;
        }
        b bVar = bVarArr[0];
        if ("0999666666".equalsIgnoreCase(bVar.b)) {
            try {
                Thread.sleep(1000);
                return new c(this) {
                    final /* synthetic */ f a;

                    {
                        this.a = r2;
                        this.b = 0;
                        this.c = "";
                        this.d = "1234567890";
                    }
                };
            } catch (InterruptedException e) {
                return anonymousClass1;
            }
        }
        try {
            HttpClientRequest httpClientRequest = new HttpClientRequest(Type.POST, "https://oauth.zaloapp.com/v2/mobile/register/req-active-code");
            httpClientRequest.addParams("app_id", ZaloSDK.Instance.getAppID());
            httpClientRequest.addParams("pkg_name", this.b.getPackageName());
            httpClientRequest.addParams("sign_key", AppInfo.getApplicationHashKey(this.b));
            httpClientRequest.addParams("zdId", ZaloSDK.Instance.getDeviceId());
            httpClientRequest.addParams("sdkId", ZaloSDK.Instance.getSDKId());
            httpClientRequest.addParams("conn", Utils.getConnectionType(this.b));
            httpClientRequest.addParams("mod", Utils.getDeviceModel());
            httpClientRequest.addParams("heap", Utils.getHeapSize());
            httpClientRequest.addParams("deviceWidth", String.valueOf(Utils.getScreenWidth(this.b)));
            httpClientRequest.addParams("deviceHeight", String.valueOf(Utils.getScreenHeight(this.b)));
            httpClientRequest.addParams("imei", Utils.getIMEI(this.b));
            httpClientRequest.addParams("localTime", String.valueOf(System.currentTimeMillis()));
            httpClientRequest.addParams("timeZone", Utils.getTimeZoneString());
            httpClientRequest.addParams("cpuProcessor", Utils.getCPUInfo());
            httpClientRequest.addParams("battery", Utils.getBatteryInfo());
            httpClientRequest.addParams("phone", bVar.b);
            httpClientRequest.addParams("regionCode", bVar.c);
            httpClientRequest.addParams("isForgotPwd", bVar.a ? "1" : "0");
            httpClientRequest.addParams("lang", com.zing.zalo.zalosdk.payment.direct.Utils.getLanguage(this.b));
            Log.i("debuglog", "lang submit to server: " + com.zing.zalo.zalosdk.payment.direct.Utils.getLanguage(this.b));
            String text = httpClientRequest.getText();
            JSONObject jSONObject = new JSONObject(text);
            anonymousClass1.b = jSONObject.optInt("error", -1);
            anonymousClass1.c = jSONObject.optString("errorMsg", anonymousClass1.c);
            anonymousClass1.e = text;
            JSONObject optJSONObject = jSONObject.optJSONObject("data");
            if ((anonymousClass1.b != 0 && anonymousClass1.b != -1031) || optJSONObject == null) {
                return anonymousClass1;
            }
            anonymousClass1.d = optJSONObject.optString("token", "");
            return anonymousClass1;
        } catch (Exception e2) {
            Log.e(e2);
            return anonymousClass1;
        }
    }

    protected final /* synthetic */ Object doInBackground(Object[] objArr) {
        return a((b[]) objArr);
    }

    protected final /* synthetic */ void onPostExecute(Object obj) {
        c cVar = (c) obj;
        super.onPostExecute(cVar);
        if (this.a != null) {
            this.a.a(cVar);
        }
        this.a = null;
    }
}
